Module dependency

Module dependency 

Dependencies.

Modules

either
The enum Either with variants Left and Right is a general purpose sum type with two cases.
type_constructor
Fundamental data types and type constructors, like Single, Pair, Many.
winterval
Interval adapter for both open/closed implementations of intervals ( ranges ).