Module prelude

Module prelude 

Prelude to use essentials: use my_module::prelude::*.

Macros

_impls_callback
Internal impls1 macro. Don’t use.
fn_name
Get name of a function.
fn_rename
Macro to rename function.
fns
Split functions.
fns2
Split functions.
impls
Define implementation putting each function under a macro.
impls1
Define implementation putting each function under a macro.
impls2
Define implementation putting each function under a macro.
impls3
Macros to put each function under a named macro to index every function in a class.
index
Index of items.
tests_impls
Define implementation putting each function under a macro and adding attribute #[ test ].
tests_impls_optional
Define implementation putting each function under a macro and adding attribute #[ test ].
tests_index
Index of items.