Module dependency

Module dependency 

Dependencies.

Modules

for_each
Apply macro for each element of a list.
former
Former - variation of builder pattern.
impls_index
Several of macros to put each function under a named macro to index every function in a class.
literally
When you literally just want a literal of the std::collections types.
paste
githubcrates-iodocs-rs
woptions
Mechanism to define map of options for a function and its defaults laconically.