Module protected

Module protected 

Protected namespace of the module.

Macros

Options
Function-like macro to generate options adapter and its implementation for structure option.
_impls_callback
Internal impls1 macro. Don’t use.
bmap
Literally just a BTreeMap literal with keys and values into’d.
braces_unwrap
Unwrap braces of token tree and pass its content to the passed callback. If token tree in not braced then it passed to callback as is.
bset
Literally just a BTreeSet literal with values into’d.
fn_name
Get name of a function.
fn_rename
Macro to rename function.
fns
Split functions.
fns2
Split functions.
for_each
Module :: for_each
heap
Literally just a BinaryHeap literal with values into’d.
hmap
Literally just a HashMap literal with keys and values into’d.
hset
Literally just a HashSet literal with values into’d.
identity
Macro which returns its input as is.
idents_concat
impls
Define implementation putting each function under a macro.
impls1
Define implementation putting each function under a macro.
impls2
Define implementation putting each function under a macro.
impls3
Macros to put each function under a named macro to index every function in a class.
index
Index of items.
list
Literally just a LinkedList literal with values into’d.
mod_interface
Protocol of modularity unifying interface of a module and introducing layers.
tests_impls
Define implementation putting each function under a macro and adding attribute #[ test ].
tests_impls_optional
Define implementation putting each function under a macro and adding attribute #[ test ].
tests_index
Index of items.
vecd
Literally just a VecDeque literal with values into’d.

Derive Macros

Former
Derive macro to generate former for a structure. Former is variation of Builder Pattern.