Macro wtest_basic::test_suite
source · [−]macro_rules! test_suite {
() => { ... };
(
$( #[ $Meta : meta ] )*
$Name : ident ,
$( $Rest : tt )*
) => { ... };
}Expand description
Mechanism to define test suite. This macro encourages refactoring the code of the test in the most readable way, gathering a list of all test routines at the end of the test file.
Name of test routine should have postfix *_test. In the index of test routine the postfix should be ommited.
Sample
use wtest_basic::*;
//
fn pass1_test() { assert_eq!( true, true ); }
//
fn pass2_test() { assert_eq!( 1, 1 ); }
//
test_suite! { pass1, pass2, }